==> cdktf_cdktf_provider_azurerm-0.5.60-py3-none-any.whl: package/lib/data-azurerm-public-ip.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermPublicIpConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#name DataAzurermPublicIp#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#resource_group_name DataAzurermPublicIp#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#timeouts DataAzurermPublicIp#timeouts}
    */
    readonly timeouts?: DataAzurermPublicIpTimeouts;
}
export interface DataAzurermPublicIpTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#read DataAzurermPublicIp#read}
    */
    readonly read?: string;
}
export declare function dataAzurermPublicIpTimeoutsToTerraform(struct?: DataAzurermPublicIpTimeoutsOutputReference | DataAzurermPublicIpTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermPublicIpTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermPublicIpTimeouts | undefined;
    set internalValue(value: DataAzurermPublicIpTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip azurerm_public_ip}
*/
export declare class DataAzurermPublicIp extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip azurerm_public_ip} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermPublicIpConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermPublicIpConfig);
    get allocationMethod(): string;
    get domainNameLabel(): string;
    get fqdn(): string;
    get id(): string;
    get idleTimeoutInMinutes(): number;
    get ipAddress(): string;
    ipTags(key: string): string | cdktf.IResolvable;
    get ipVersion(): string;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get reverseFqdn(): string;
    get sku(): string;
    tags(key: string): string | cdktf.IResolvable;
    get zones(): string[];
    private _timeouts;
    get timeouts(): DataAzurermPublicIpTimeoutsOutputReference;
    putTimeouts(value: DataAzurermPublicIpTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermPublicIpTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.6.24-py3-none-any.whl: package/lib/data-azurerm-public-ip.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermPublicIpConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#name DataAzurermPublicIp#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#resource_group_name DataAzurermPublicIp#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#timeouts DataAzurermPublicIp#timeouts}
    */
    readonly timeouts?: DataAzurermPublicIpTimeouts;
}
export interface DataAzurermPublicIpTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip#read DataAzurermPublicIp#read}
    */
    readonly read?: string;
}
export declare function dataAzurermPublicIpTimeoutsToTerraform(struct?: DataAzurermPublicIpTimeoutsOutputReference | DataAzurermPublicIpTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermPublicIpTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermPublicIpTimeouts | undefined;
    set internalValue(value: DataAzurermPublicIpTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip azurerm_public_ip}
*/
export declare class DataAzurermPublicIp extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_public_ip";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/public_ip azurerm_public_ip} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermPublicIpConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermPublicIpConfig);
    get allocationMethod(): string;
    get domainNameLabel(): string;
    get fqdn(): string;
    get id(): string;
    get idleTimeoutInMinutes(): number;
    get ipAddress(): string;
    ipTags(key: string): string | cdktf.IResolvable;
    get ipVersion(): string;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get reverseFqdn(): string;
    get sku(): string;
    tags(key: string): string | cdktf.IResolvable;
    get zones(): string[];
    private _timeouts;
    get timeouts(): DataAzurermPublicIpTimeoutsOutputReference;
    putTimeouts(value: DataAzurermPublicIpTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermPublicIpTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
